# frozen_string_literal: true

# SPDX-License-Identifier: Apache-2.0

require "tty/option"
require "gitlab-to-doap"

class GitlabToDoap::Command
  include TTY::Option

  usage do
    program "gitlab-to-doap"
    banner "Usage: #{program} [OPTIONS] user/project"

    description "Print out a DOAP XML document of a given Gitlab project"
  end

  flag :help do
    short "-h"
    long "--help"
    desc "Print usage"
  end

  flag :version do
    short "-v"
    long "--version"
    desc "Print version"
  end

  argument :project

  environment :gitlab_endpoint do
    name "GITLAB_API_ENDPOINT"
    # validate ->({ |v| URI.parse(v) && v.ends_with? "/api/v4" })
    desc "Full URL to the Gitlab instance. Must end with /api/v4"
  end

  environment :gitlab_token do
    name "GITLAB_API_PRIVATE_TOKEN"
    desc "Your personal access token to the Gitlab instance."
  end

  option :file do
    short "-f"
    long "--file"
    desc "Send the generated XML to a file, rather than STDOUT."
    optional
  end

  def run
    g2d = GitlabToDoap.new(params[:gitlab_endpoint], params[:gitlab_token])
    project = g2d.gitlab_project(params[:project])
    xml = g2d.doap_xml(project)

    if params[:file]
      # output_filename = project.path_with_namespace.gsub(/\W/, "-") + ".doap.xml"
      File.open(params[:file], "w") do |f|
        f.puts xml
      end
    else
      puts xml
    end
  end
end
