# frozen_string_literal: true

# SPDX-License-Identifier: Apache-2.0

require "gitlab"
require "redcarpet"
require "redcarpet/render_strip"

module GitlabToDoap::Utilities
  attr_reader :gitlab_endpoint
  attr_reader :gitlab_api_token

  # Given some markdown formatted plain text, remove all of the formatting
  def strip_markdown(text)
    markdown = Redcarpet::Markdown.new(Redcarpet::Render::StripDown)
    markdown.render(text).strip
  end

  # Build a Gitlab API client, if one does not exist already
  def gitlab
    @gitlab ||= Gitlab.client(
      endpoint: @gitlab_endpoint,
      private_token: @gitlab_api_token
    )
  end

  def gitlab_project(project_id)
    gitlab.get("/projects/#{gitlab.url_encode project_id}?license=true&statistics=true")
  end
end
